<?php
/*
Plugin Name: Divi Learndash Kit
Plugin URI: 
Description: Improves integration between Divi and Learndash
Author: Divi Booster
Version: 1.2.1
Author URI: http://www.divibooster.com
*/

// Run unit tests if applicable
if (defined('DBDLK_UNIT_TESTS') && DBDLK_UNIT_TESTS && file_exists(dirname(__FILE__).'/tests/tests.php')) {
	include_once(dirname(__FILE__).'/tests/tests.php');
}

define('DLK_VERSION', '1.2.1');
define('DLK_VERSION_OPTION', 'divi-learndash-kit');
define('DLK_PATH', dirname(__FILE__).'/');

// === Updates ===
include_once(DLK_PATH.'plugin-update-checker.php');
$updatename = 'divi-learndash-kit';
$updateurl = 'https://d2hmoepawdq173.cloudfront.net/updates.json'; 
// include_once(DLK_PATH.'updates/plugin-update-checker.php');
try {
	$MyUpdateChecker = new DB_DLK_PluginUpdateChecker_1_0_0($updateurl, __FILE__, $updatename);
} catch (Exception $e) { echo "Update error: ".$e->getMessage(); exit; }


// Load the helper functions
include_once(DLK_PATH.'functions.php');

// Supported post types
function dlk_get_learndash_post_types() {
	return array(
		'sfwd-courses',			// learndash courses
		'sfwd-lessons',			// learndash lessons,
		'sfwd-quiz',			// learndash quizzes
		'sfwd-topic',			// learndash topics
		'sfwd-certificates',	// learndash certificates
		'groups'				// learndash groups
	);
}

// Load the settings
include_once(DLK_PATH.'admin/settings-page.php');

// Enable Divi Builder / Page Layout options
add_filter('et_builder_post_types', 'dlk_add_post_types');
add_action('add_meta_boxes', 'dlk_add_meta_boxes');
add_action('wp_enqueue_scripts', 'dlk_enqueue_user_scripts');
add_action('admin_enqueue_scripts', 'dlk_enqueue_admin_css');


// Do update actions
include_once(DLK_PATH.'update_actions.php');

// Testing
if (defined('DLK_DISABLE_LOCAL_CACHING')) { 
	dlk_clear_module_local_storage();
}

include_once(DLK_PATH.'modules/modules.php');

// === Enqueue LearnDash Course Grid files if needed ===

add_action("wp_enqueue_scripts", "dlk_enqueue_course_grid_files");

function dlk_enqueue_course_grid_files() {
	
	if (defined('LEARNDASH_COURSE_GRID_FILE')) { // Course Grid add-on installed
		
		if (function_exists('learndash_course_grid_load_resources')) { // Course Grid 1.5+
			learndash_course_grid_load_resources();
			
		} else { // Course Grid pre-1.5
			wp_enqueue_style( 'learndash_course_grid_css', plugins_url( 'style.css', LEARNDASH_COURSE_GRID_FILE) );
			wp_enqueue_script( 'learndash_course_grid_js', plugins_url( 'script.js', LEARNDASH_COURSE_GRID_FILE), array('jquery' ) );
			wp_enqueue_style( 'ld-cga-bootstrap', plugins_url( 'bootstrap.min.css', LEARNDASH_COURSE_GRID_FILE) );
		}
	}
}

// === Enable Divi Builder on Learndash CPTs === //

/* Handle option to use single shared libary */
$shared_library = false;
if ($shared_library) {
	add_filter('et_pb_show_all_layouts_built_for_post_type', 'dlk_use_page_layout_library_for_cpts');
}
function dlk_use_page_layout_library_for_cpts() { return 'page'; }

/* Enable Divi Builder on all post types with an editor box */
function dlk_add_post_types($post_types) {
	foreach(dlk_get_learndash_post_types() as $pt) {
		if (!in_array($pt, $post_types) and post_type_supports($pt, 'editor')) {
			$post_types[] = $pt;
		}
	} 
	return $post_types;
}

/* Make [user_groups] shortcode render Divi Builder content from Group CPT */
add_filter( 'do_shortcode_tag','dlk_process_shortcodes_in_user_groups',10,3);
function dlk_process_shortcodes_in_user_groups($output, $tag, $attr){
  if('user_groups' != $tag){ //make sure it is the right shortcode
    return $output;
  }
  return do_shortcode($output);
}

/* Add Divi Custom Post Settings box */
function dlk_add_meta_boxes() {
	foreach(dlk_get_learndash_post_types() as $pt) {
		if (post_type_supports($pt, 'editor') and function_exists('et_single_settings_meta_box')) {
			add_meta_box('et_settings_meta_box', __('Divi Custom Post Settings', 'Divi'), 'et_single_settings_meta_box', $pt, 'side', 'high');
		}
	} 
}

// Admin css to enable page layout settings
function dlk_enqueue_admin_css() { 
	wp_enqueue_style('divi-learndash-kit', plugins_url('admin/admin.css', __FILE__), array(), DLK_VERSION);
};

function dlk_enqueue_user_scripts() { 
	wp_enqueue_style('divi-learndash-kit', plugins_url('style.css', __FILE__), array(), DLK_VERSION);	
	wp_enqueue_script('divi-learndash-kit', plugins_url('script.js', __FILE__), array('jquery'), DLK_VERSION);	
};

/* Add option to show / hide the post title */
add_action('admin_head', 'dlk_add_show_title_option_to_metabox');
add_filter('body_class', 'dlk_add_show_title_body_class');

function dlk_add_show_title_option_to_metabox() { 
	global $post;
	
	if (in_array($post->post_type, dlk_get_learndash_post_types())) {
		$show_title = $post->_et_pb_show_title;
		?>
		<script>
		jQuery(function($){
			$('#et_settings_meta_box .inside').append($('<p class="et_pb_page_settings et_pb_single_title"><label for="et_single_title" style="display: block; font-weight: bold; margin-bottom: 5px;"><?php esc_html_e( 'Post Title', 'Divi' ); ?>: </label><select id="et_single_title" name="et_single_title"><option value="on" <?php echo str_replace("'", '"', selected( 'on', $show_title, false) ); ?>><?php esc_html_e( 'Show', 'Divi' ); ?></option><option value="off" <?php echo str_replace("'", '"', selected( 'off', $show_title, false)); ?>><?php esc_html_e( 'Hide', 'Divi' ); ?></option></select></p>'));
		});
		</script>
		<?php
	}
}

function dlk_add_show_title_body_class($classes) {
	global $post;
	
	if (in_array($post->post_type, dlk_get_learndash_post_types())) {
		$show_default_title = $post->_et_pb_show_title;
		if ($show_default_title !== 'on') {
			$classes[] = 'dlk_hide_post_title';
		}
	}
	return $classes;
}

/* === Add option to hide default course content box and course status on courses === */

add_action('admin_head', 'dlk_add_hide_course_content_option');
add_action('save_post', 'dlk_divi_post_settings_save_details', 10, 2);
add_filter('body_class', 'dlk_add_hide_course_content_class');

function dlk_add_hide_course_content_option() { 
	global $post;
	
	if ($post->post_type === 'sfwd-courses') {
		$show_course_content = $post->_dlk_show_course_content;
		$show_course_status = $post->_dlk_show_course_status;
		?>
		<script>
		jQuery(function($){
			
			// Add course content drop down
			$('#et_settings_meta_box .inside').append(
				$('<p class="et_pb_page_settings db_pb_course_content_box"><label for="dlk_show_course_content" style="display: block; font-weight: bold; margin-bottom: 5px;">Course Content: </label><select id="dlk_show_course_content" name="dlk_show_course_content"><option value="on" <?php echo str_replace("'", '"', selected('on', $show_course_content, false)); ?>><?php esc_html_e('Show', 'Divi'); ?></option><option value="off" <?php echo str_replace("'", '"', selected('off', $show_course_content, false)); ?>><?php esc_html_e('Hide', 'Divi'); ?></option></select></p>')
			);
			
			// Add course status drop down
			$('#et_settings_meta_box .inside').append(
				$('<p class="et_pb_page_settings db_pb_course_status_box"><label for="dlk_show_course_status" style="display: block; font-weight: bold; margin-bottom: 5px;">Course Status: </label><select id="dlk_show_course_status" name="dlk_show_course_status"><option value="on" <?php echo str_replace("'", '"', selected('on', $show_course_status, false)); ?>><?php esc_html_e('Show', 'Divi'); ?></option><option value="off" <?php echo str_replace("'", '"', selected('off', $show_course_status, false)); ?>><?php esc_html_e('Hide', 'Divi'); ?></option></select></p>')
			);
		});
		</script>
		<?php
	}
}

// Save the course content setting in the post meta
function dlk_divi_post_settings_save_details($post_id, $post){
	global $pagenow;

	// Do nothing if not a post
	if ('post.php' !== $pagenow || !$post || !is_object($post)) { return; }
	
	// Do nothing if this is an autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) { return; }

	// Do nothing if user can't edit CPT
	$post_type = get_post_type_object($post->post_type);
	if (!current_user_can($post_type->cap->edit_post, $post_id)) { return; }
	
	// Do nothing if ET nonce is wrong. 
	// NB: main metabox nonce uses basename(__FILE__) as context which evaluates to 'functions.php'
	if (!isset($_POST['et_settings_nonce']) || !wp_verify_nonce($_POST['et_settings_nonce'], 'functions.php')) { return; } 

	// Set or remove the course content post meta field as appropriate
	$show_course_content = (isset($_POST['dlk_show_course_content']) && $_POST['dlk_show_course_content'] !== 'off');
	update_post_meta($post_id, '_dlk_show_course_content', $show_course_content?'on':'off');
	
	// Set or remove the course status post meta field as appropriate
	$show_course_status = (isset($_POST['dlk_show_course_status']) && $_POST['dlk_show_course_status'] !== 'off');
	update_post_meta($post_id, '_dlk_show_course_status', $show_course_status?'on':'off');
}

function dlk_add_hide_course_content_class($classes) {
	global $post;
	
	// Add class when course content hidden
	if ($post->post_type === 'sfwd-courses' && $post->_dlk_show_course_content === 'off') {
		$classes[] = 'dlk_hide_course_content';
	}
	
	// Add class when course content hidden
	if ($post->post_type === 'sfwd-courses' && $post->_dlk_show_course_status === 'off') {
		$classes[] = 'dlk_hide_course_status';
	}
	
	return $classes;
}

// === Add fullwidth option to metaboxes (needed for Divi 3.9ish+ which disables fullwidth on CPTs) ===

add_action('admin_head', 'dlk_add_fullwidth_option_to_metabox');

function dlk_add_fullwidth_option_to_metabox() { 
	global $post;
	
	if (in_array($post->post_type, dlk_get_learndash_post_types())) {
		$selected = (get_post_meta(get_the_ID(), '_et_pb_page_layout', true) === 'et_full_width_page');
		?>
		<script>
		jQuery(function($){
			var $select = $('select#et_pb_page_layout');
			if ($select.find('option[value="et_full_width_page"]').length == 0) {
				$select.append($('<option value="et_full_width_page"><?php esc_html_e('Fullwidth', 'Divi'); ?></option>'));
				<?php if ($selected) { ?>
					$select.val('et_full_width_page');
				<?php } ?>
			}
		});
		</script>
		<?php
	}
}